3 ms·
I refactored it to be more static and final/const. Also used an int[][] for the node data. Original comment is on proggit. Went from 1600ms to 900ms. http://p
by super_tycoon 12y ago
I refactored it to be more static and final/const. Also used an int[][] for the node data.
Original comment is on proggit. Went from 1600ms to 900ms.
http://pastebin.com/w2BC8fNg http://pastebin.com/w2BC8fNg
http://www.reddit.com/r/programming/comments/2pvf68/armv7_vs_x8664_pathfinding_benchmark_of_c_d_go/cn0ft71 http://www.reddit.com/r/programming/comments/2pvf68/armv7_vs...